@@ -2,8 +2,9 @@
 
 from __future__ import annotations
 
-from .ablation import AblationGame
+from .ablation import AblationGame, MultiBaselineAblationGame
 from .abstract import AbstractHPIGame
+from .multi_data import MultiDataHPIGame
 from .optimizerbias import OptimizerBiasGame
 from .tunability import MistunabilityGame, SearchBasedGame, SensitivityGame, TunabilityGame
 
@@ -11,6 +12,8 @@ __all__ = [
     "AblationGame",
     "AbstractHPIGame",
     "MistunabilityGame",
+    "MultiBaselineAblationGame",
+    "MultiDataHPIGame",
     "OptimizerBiasGame",
     "SearchBasedGame",
     "SensitivityGame",
